@@ -91,7 +91,7 @@ class Exceptions:
 
 class AccessAnalyzerClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html)
     """
 
@@ -102,19 +102,19 @@ class AccessAnalyzerClient:
         self, *, analyzerArn: str, ruleName: str, clientToken: str = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.apply_archive_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.apply_archive_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#apply_archive_rule)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#can_paginate)
         """
 
-    def cancel_policy_generation(self, jobId: str) -> Dict[str, Any]:
+    def cancel_policy_generation(self, *, jobId: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.cancel_policy_generation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.cancel_policy_generation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#cancel_policy_generation)
         """
 
@@ -126,7 +126,7 @@ class AccessAnalyzerClient:
         clientToken: str = None
     ) -> CreateAccessPreviewResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_access_preview)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_access_preview)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#create_access_preview)
         """
 
@@ -140,7 +140,7 @@ class AccessAnalyzerClient:
         tags: Dict[str, str] = None
     ) -> CreateAnalyzerResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_analyzer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_analyzer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#create_analyzer)
         """
 
@@ -153,13 +153,13 @@ class AccessAnalyzerClient:
         clientToken: str = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_archive_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_archive_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#create_archive_rule)
         """
 
-    def delete_analyzer(self, analyzerName: str, clientToken: str = None) -> None:
+    def delete_analyzer(self, *, analyzerName: str, clientToken: str = None) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_analyzer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_analyzer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#delete_analyzer)
         """
 
@@ -167,7 +167,7 @@ class AccessAnalyzerClient:
         self, *, analyzerName: str, ruleName: str, clientToken: str = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_archive_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_archive_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#delete_archive_rule)
         """
 
@@ -179,41 +179,43 @@ class AccessAnalyzerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#generate_presigned_url)
         """
 
     def get_access_preview(
-        self, accessPreviewId: str, analyzerArn: str
+        self, *, accessPreviewId: str, analyzerArn: str
     ) -> GetAccessPreviewResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_access_preview)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_access_preview)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_access_preview)
         """
 
     def get_analyzed_resource(
-        self, analyzerArn: str, resourceArn: str
+        self, *, analyzerArn: str, resourceArn: str
     ) -> GetAnalyzedResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzed_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzed_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_analyzed_resource)
         """
 
-    def get_analyzer(self, analyzerName: str) -> GetAnalyzerResponseTypeDef:
+    def get_analyzer(self, *, analyzerName: str) -> GetAnalyzerResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_analyzer)
         """
 
-    def get_archive_rule(self, analyzerName: str, ruleName: str) -> GetArchiveRuleResponseTypeDef:
+    def get_archive_rule(
+        self, *, analyzerName: str, ruleName: str
+    ) -> GetArchiveRuleResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_archive_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_archive_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_archive_rule)
         """
 
-    def get_finding(self, analyzerArn: str, id: str) -> GetFindingResponseTypeDef:
+    def get_finding(self, *, analyzerArn: str, id: str) -> GetFindingResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_finding)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_finding)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_finding)
         """
 
@@ -225,7 +227,7 @@ class AccessAnalyzerClient:
         includeServiceLevelTemplate: bool = None
     ) -> GetGeneratedPolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_generated_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_generated_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_generated_policy)
         """
 
@@ -239,7 +241,7 @@ class AccessAnalyzerClient:
         nextToken: str = None
     ) -> ListAccessPreviewFindingsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_preview_findings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_preview_findings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_access_preview_findings)
         """
 
@@ -247,7 +249,7 @@ class AccessAnalyzerClient:
         self, *, analyzerArn: str, maxResults: int = None, nextToken: str = None
     ) -> ListAccessPreviewsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_previews)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_previews)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_access_previews)
         """
 
@@ -260,7 +262,7 @@ class AccessAnalyzerClient:
         resourceType: ResourceTypeType = None
     ) -> ListAnalyzedResourcesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzed_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzed_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_analyzed_resources)
         """
 
@@ -268,7 +270,7 @@ class AccessAnalyzerClient:
         self, *, maxResults: int = None, nextToken: str = None, type: TypeType = None
     ) -> ListAnalyzersResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_analyzers)
         """
 
@@ -276,7 +278,7 @@ class AccessAnalyzerClient:
         self, *, analyzerName: str, maxResults: int = None, nextToken: str = None
     ) -> ListArchiveRulesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_archive_rules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_archive_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_archive_rules)
         """
 
@@ -290,7 +292,7 @@ class AccessAnalyzerClient:
         sort: SortCriteriaTypeDef = None
     ) -> ListFindingsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_findings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_findings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_findings)
         """
 
@@ -298,13 +300,13 @@ class AccessAnalyzerClient:
         self, *, maxResults: int = None, nextToken: str = None, principalArn: str = None
     ) -> ListPolicyGenerationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_policy_generations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_policy_generations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_policy_generations)
         """
 
-    def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
+    def list_tags_for_resource(self, *, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_tags_for_resource)
         """
 
@@ -316,25 +318,25 @@ class AccessAnalyzerClient:
         cloudTrailDetails: CloudTrailDetailsTypeDef = None
     ) -> StartPolicyGenerationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.start_policy_generation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.start_policy_generation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#start_policy_generation)
         """
 
-    def start_resource_scan(self, analyzerArn: str, resourceArn: str) -> None:
+    def start_resource_scan(self, *, analyzerArn: str, resourceArn: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.start_resource_scan)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.start_resource_scan)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#start_resource_scan)
         """
 
-    def tag_resource(self, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
+    def tag_resource(self, *, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#tag_resource)
         """
 
-    def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#untag_resource)
         """
 
@@ -347,7 +349,7 @@ class AccessAnalyzerClient:
         clientToken: str = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_archive_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_archive_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#update_archive_rule)
         """
 
@@ -361,7 +363,7 @@ class AccessAnalyzerClient:
         resourceArn: str = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_findings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_findings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#update_findings)
         """
 
@@ -375,7 +377,7 @@ class AccessAnalyzerClient:
         nextToken: str = None
     ) -> ValidatePolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Client.validate_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Client.validate_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#validate_policy)
         """
 
@@ -384,7 +386,7 @@ class AccessAnalyzerClient:
         self, operation_name: Literal["list_access_preview_findings"]
     ) -> ListAccessPreviewFindingsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listaccesspreviewfindingspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listaccesspreviewfindingspaginator)
         """
 
     @overload
@@ -392,7 +394,7 @@ class AccessAnalyzerClient:
         self, operation_name: Literal["list_access_previews"]
     ) -> ListAccessPreviewsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listaccesspreviewspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listaccesspreviewspaginator)
         """
 
     @overload
@@ -400,13 +402,13 @@ class AccessAnalyzerClient:
         self, operation_name: Literal["list_analyzed_resources"]
     ) -> ListAnalyzedResourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listanalyzedresourcespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listanalyzedresourcespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_analyzers"]) -> ListAnalyzersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listanalyzerspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listanalyzerspaginator)
         """
 
     @overload
@@ -414,13 +416,13 @@ class AccessAnalyzerClient:
         self, operation_name: Literal["list_archive_rules"]
     ) -> ListArchiveRulesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listarchiverulespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listarchiverulespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_findings"]) -> ListFindingsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listfindingspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listfindingspaginator)
         """
 
     @overload
@@ -428,11 +430,11 @@ class AccessAnalyzerClient:
         self, operation_name: Literal["list_policy_generations"]
     ) -> ListPolicyGenerationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListPolicyGenerations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listpolicygenerationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListPolicyGenerations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listpolicygenerationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["validate_policy"]) -> ValidatePolicyPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#validatepolicypaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#validatepolicypaginator)
         """
